**Example 1: 创建告警通知接收组**



Input: 

```
tccli pts CreateAlertChannel --cli-unfold-argument  \
    --ProjectId xx \
    --NoticeId xx \
    --AMPConsumerId xx
```

Output: 
```
{
    "Response": {
        "RequestId": "xx"
    }
}
```

